@@ -1,13 +1,17 @@
 """
-Module for expressing CRNs and deriving their ODEs. Ideas and much code taken from
+Module for expressing chemical reaction networks and deriving their ODEs. Ideas and much code taken from
 https://github.com/enricozb/python-crn.
 
 For example, to specify the "approximate majority" reactions
 (see https://doi.org/10.1007/978-3-540-75142-7_5 or https://doi.org/10.1126/science.aal2052)
 
-    | A+B → 2U
-    | A+U → 2A
-    | B+U → 2B
+.. math::
+
+    A+B \\to 2U
+
+    A+U \\to 2A
+
+    B+U \\to 2B
 
 we can write
 
@@ -15,42 +19,38 @@ we can write
 
     a, b, u = species('A B U')
     rxns = [
-        a + b >> 2 * u,
-        a + u >> 2 * a,
-        b + u >> 2 * b,
+        a+b >> 2*u,
+        a+u >> 2*a,
+        b+u >> 2*b,
     ]
-    n = 10 ** 5
-    init_config = {a: 0.51 * n, b: 0.49 * n}
+    initial_values = {a: 0.51, b: 0.49}
     t_eval = np.linspace(0, 10, 100)
-    gpac.plot_crn(rxns, init_config, t_eval)
+    gpac.plot_crn(rxns, initial_values, t_eval)
 
-which will plot the concentrations of A, B, and U over time.
+which will plot the concentrations of A, B, and U over time. One can specify reversible reactions
+by using the ``|`` operator instead of ``>>`` (e.g., ``a+b | 2*u``) and rate constants using the functions
+``k`` (for forward rate constants) and ``r`` (for reverse rate constants),
+e.g., ``(a+b | 2*u).k(1.5).r(0.5)``.
 
-See functions :func:`crn.crn_to_odes` to convert reactions to ODEs (ordinary differential equations),
-:func:`crn.integrate_crn_odes` to get the trajectories of integrating these ODEs over time, and
-:func:`crn.plot_crn` to plot the trajectories. The documentation for :func:`crn.crn_to_odes` explains
+See functions :func:`crn_to_odes` to convert reactions to ODEs (ordinary differential equations),
+:func:`integrate_crn_odes` to get the trajectories of integrating these ODEs over time, and
+:func:`plot_crn` to plot the trajectories. The documentation for :func:`crn_to_odes` explains
 how reactions are converted into ODEs by each of these functions.
 """
 
 from __future__ import annotations  # needed for forward references in type hints
 
+from typing import Dict, Iterable, Tuple, Set, Union, Optional, Callable, List
 from collections import defaultdict
 import copy
-from gpac import integrate_odes, plot
-
 from dataclasses import dataclass
 
-from typing import Dict, Iterable, Tuple, Set, Union, Optional, Callable, List
-
-import scipy.integrate
+from scipy.integrate import OdeSolver
 from scipy.integrate._ivp.ivp import OdeResult
 import sympy
 
-#         | X+X →\ :sup:`k1` C
-#         | C+X →\ :sup:`k2` C+Y
-#         | x' = -2 k1 x\ :sup:`2` - k2 c x
-#         | c' = k1 x\ :sup:`2`
-#         | y' = k2 c x
+from gpac import integrate_odes, plot
+
 
 def crn_to_odes(rxns: Iterable[Reaction]) -> Dict[sympy.Symbol, sympy.Expr]:
     """
@@ -58,22 +58,58 @@ def crn_to_odes(rxns: Iterable[Reaction]) -> Dict[sympy.Symbol, sympy.Expr]:
 
     Each reaction contributes one term to the ODEs for each species produced or consumed in it.
     The term from a reaction appearing in the ODE for species `X` is the product of:
-    the rate constant,
-    the reactant concentrations,
-    and the net stoichiometry of species `X` in the reaction
-    (i.e., the net amount of `X` produced by the reaction, negative if consumed).
-    For example, the CRN
 
-        | :math:`X+X \\xrightarrow{k_1} C`
-        | :math:`C+X \\xrightarrow{k_2} C+Y`
+    - the rate constant,
+    - the reactant concentrations, and
+    - the net stoichiometry of species `X` in the reaction
+      (i.e., the net amount of `X` produced by the reaction, negative if consumed).
 
+    For example, consider the following two reactions with respective rate constants
+    :math:`k_1` and :math:`k_2`:
 
-    where :math:`k_1`, :math:`k_2` are the rate constants of the two reactions,
-    corresponds to ODEs (following the convention of lowercase letter `x` for concentration of species `X`):
+    .. math::
 
-        | :math:`x' = -2 k_1 x^2 - k2 c x`
-        | :math:`c' = k_1 x^2`
-        | :math:`y' = k_2 c x`
+        X+X &\\xrightarrow{k_1} C
+
+        C+X &\\xrightarrow{k_2} C+Y
+
+    The net stoichiometry of `X` in the first reaction is -2, since two copies of `X` are consumed,
+    and the net stoichiometry of `C` in that reaction is 1, since one copy of `C` is produced.
+    The net stoichiometry of `C` in the *second* reaction is 0, since it is a catalyst
+    (neither produced nor consumed).
+
+    This corresponds to ODEs (following the convention of lowercase letter `x`
+    for the concentration of species `X`):
+
+    .. math::
+
+        x' &= -2 k_1 x^2 - k_2 c x
+
+        c' &= k_1 x^2
+
+        y' &= k_2 c x
+
+    In the package, this can be implemented (for example setting :math:`k_1 = 1.5` and :math:`k_2 = 0.2`)
+    via:
+
+    .. code-block:: python
+
+        x, y, c = species('X Y C')
+        rxns = [
+            (x+x >> c).k(1.5),
+            (c+x >> c+y).k(0.2),
+        ]
+        odes = crn_to_odes(rxns)
+        for symbol, ode in odes.items():
+            print(f"{symbol}' = {ode}")
+
+    which prints
+
+    .. code-block:: none
+
+        X' = -0.2*C*X - 3.0*X**2
+        C' = 1.5*X**2
+        Y' = 0.2*C*X
 
     Args:
         rxns: list of :any:`Reaction`'s comprising the chemical reaction network.
@@ -82,8 +118,9 @@ def crn_to_odes(rxns: Iterable[Reaction]) -> Dict[sympy.Symbol, sympy.Expr]:
     Returns:
         Dictionary mapping each species (represented as a sympy Symbol object, rather than a :any:`Specie`
         object) to its corresponding ODE (represented as a sympy Expression).
-        This object can be given to the functions :func:`gpac.integrate_odes` or :func:`gpac.plot`
-        to integrate/plot the ODEs.
+        This object can be given as the parameter `odes` to the functions :func:`ode.integrate_odes`
+        and :func:`ode.plot` to integrate/plot the ODEs.
+        (which is essentially all the functions :func:`integrate_crn_odes` and :func:`plot_crn` do).
     """
     # map each symbol to list of reactions in which it appears
     specie_to_rxn = defaultdict(list)
@@ -119,7 +156,7 @@ def integrate_crn_odes(
         initial_values: Dict[Specie, float],
         t_eval: Optional[Iterable[float]] = None,
         t_span: Optional[Tuple[float, float]] = None,
-        method: Union[str, scipy.integrate.OdeSolver] = 'RK45',
+        method: Union[str, OdeSolver] = 'RK45',
         dense_output: bool = False,
         events: Optional[Union[Callable, Iterable[Callable]]] = None,
         vectorized: bool = False,
@@ -128,9 +165,20 @@ def integrate_crn_odes(
 ) -> OdeResult:
     """
     Integrate the ODEs derived from to the given set of chemical reactions.
-    This calls :func:`gpac.integrate_odes` with the ODEs derived from the given reactions via
+    This calls :func:`ode.integrate_odes` with the ODEs derived from the given reactions via
     :func:`crn_to_odes`.
-    See :func:`gpac.integrate_odes` for description of parameters.
+    See :func:`ode.integrate_odes` for description of parameters other than `rxns` and `initial_values`.
+
+    Args:
+        rxns:
+            list of :any:`Reaction`'s comprising the chemical reaction network.
+            See documentation for :any:`Reaction` for details on how to specify reactions.
+
+        initial_values:
+            dict mapping each species to its initial concentration.
+            Note that unlike the parameter `initial_values` in :func:`ode.integrate_odes`,
+            keys in this dict must be :any:`Specie` objects, not strings or sympy symbols.
+
     """
     odes = crn_to_odes(rxns)
     initial_values = _normalize_crn_initial_values(initial_values)
@@ -153,9 +201,9 @@ def plot_crn(
         initial_values: Dict[Specie, float],
         t_eval: Optional[Iterable[float]] = None,
         t_span: Optional[Tuple[float, float]] = None,
-        figure_size: Tuple[float, float] = (10, 10),
+        figure_size: Tuple[float, float] = (12, 3),
         symbols_to_plot: Optional[Iterable[Union[sympy.Symbol, str]]] = None,
-        method: Union[str, scipy.integrate.OdeSolver] = 'RK45',
+        method: Union[str, OdeSolver] = 'RK45',
         dense_output: bool = False,
         events: Optional[Union[Callable, Iterable[Callable]]] = None,
         vectorized: bool = False,
@@ -164,16 +212,20 @@ def plot_crn(
 ) -> None:
     """
     Plot the ODEs derived from to the given set of chemical reactions.
-    This calls :func:`gpac.plot` with the ODEs derived from the given reactions via
+    This calls :func:`ode.plot` with the ODEs derived from the given reactions via
     :func:`crn_to_odes`.
 
-    See :func:`gpac.integrate_odes` for description of parameters. As with :func:`gpac.plot`,
-    the keyword arguments in `options` are passed to
+    See :func:`crn.integrate_crn_odes`, :func:`ode.integrate_odes`, and :func:`ode.plot`
+    for description of parameters.
+    As with :func:`ode.plot`, the keyword arguments in `options` are passed to
     matplotlib.pyplot.plot
     (https://matplotlib.org/stable/api/_as_gen/matplotlib.pyplot.plot.html),
     as well as to
     scipy.integrate.solve_ivp
-    (https://docs.scipy.org/doc/scipy/reference/generated/scipy.integrate.solve_ivp.html).
+    (https://docs.scipy.org/doc/scipy/reference/generated/scipy.integrate.solve_ivp.html),
+    and as with :func:`ode.plot`, keyword arguments not recognized by scipy.integrate.solve_ivp
+    (such as those intended for matplotlib.pyplot.plot) cause `solve_ivp` to print a warning that it
+    does not recognize the argument.
     """
     odes = crn_to_odes(rxns)
     initial_values = _normalize_crn_initial_values(initial_values)
@@ -200,7 +252,7 @@ def species(sp: Union[str, Iterable[str]]) -> Tuple[Specie, ...]:
 
     args:
         sp:
-            An string or Iterable of strings representing the names of the species being created.
+            A string or Iterable of strings representing the names of the species being created.
             If a single string, species names are interpreted as space-separated.
 
     Examples:
@@ -240,7 +292,8 @@ def replace_reversible_rxns(rxns: Iterable[Reaction]) -> List[Reaction]:
     Args:
         rxns: list of :any:`Reaction`'s
 
-    Returns: list of :any:`Reaction`'s, where every reversible reaction in `rxns` has been replaced by
+    Returns:
+        list of :any:`Reaction`'s, where every reversible reaction in `rxns` has been replaced by
         two irreversible reactions, and all others have been left as they are
     """
     new_rxns: List[Reaction] = []
@@ -313,14 +366,34 @@ class Expression:
     """
     Class used for very basic symbolic manipulation of left/right hand
     side of stoichiometric equations. Not very user friendly; users should
-    just use the `species` functions and manipulate those to get their
-    reactions.
+    just use the :func:`species` function and manipulate :any:`Specie` objects
+    with operators ``>>``, ``|``, ``+``, and ``*`` to create reactions
+    (see :any:`Reaction` for examples).
     """
 
     species: List[Specie]
-    """ordered list of species in expression, e.g, A+A+B is [A,A,B]"""
+    """
+    ordered list of species in expression, e.g, A+A+B is [A,A,B]
+    """
+
+    def __getitem__(self, idx: int) -> Specie:
+        """
+        Args:
+            idx: index of species to return
+
+        Returns:
+            :any:`Specie` at index `idx` in this :any:`Expression`
+        """
+        return self.species[idx]
 
     def __add__(self, other: Union[Expression, Specie]) -> Expression:
+        """
+        Args:
+            other: :any:`Expression` or :any:`Specie` to add to this one
+
+        Returns:
+            :any:`Expression` representing the union of this :any:`Expression` and `other`
+        """
         if isinstance(other, Expression):
             species_copy = list(self.species)
             species_copy.extend(other.species)
@@ -333,6 +406,13 @@ class Expression:
             raise NotImplementedError()
 
     def __rmul__(self, coeff: int) -> Expression:
+        """
+        Args:
+            coeff: coefficient to multiply this :any:`Expression` by
+
+        Returns:
+            :any:`Expression` representing this :any:`Expression` multiplied by `coeff`
+        """
         if isinstance(coeff, int):
             species_copy = []
             for _ in range(coeff):
@@ -367,7 +447,8 @@ class Expression:
 
 empty = Expression([])
 """
-Used for chemical reactions with empty reactant or product lists, e.g., 
+Used for chemical reactions with empty reactant or product lists, e.g., to implement the exponential
+decay reaction :math:`X \\to \\emptyset`:
 
 .. code-block:: python
     
@@ -395,21 +476,40 @@ def concentration_to_count(concentration: float, volume: float) -> int:
 @dataclass
 class Reaction:
     """
-    Representation of a stoichiometric reaction using a pair of Expressions,
+    Representation of a stoichiometric reaction using a pair of :any:`Expression`'s,
     one for the reactants and one for the products.
 
     Reactions are constructed by creating objects of type :any:`Specie` and using the operators
     ``>>`` (for irreversible reactions) and ``|`` (for reversible reactions), as well as the ``+`` and
-    ``*`` operators to specify the stoichiometric coefficients of the reactants and products. For example,
-    the following code creates a reaction that represents the irreversible reaction
-    :math:`A + B \\rightarrow C`:
+    ``*`` operators to specify the stoichiometric coefficients of the reactants and products,
+    and optionally the methods :meth:`Reaction.k` and :meth:`Reaction.r` to specify forward and reverse
+    rate constants.
+
+    For example, the following code creates a reaction that represents the irreversible reaction
+    :math:`A + B \\rightarrow C` (with implicit rate constant 1.0):
 
     .. code-block:: python
 
-        A = species('A')
-        B = species('B')
-        C = species('C')
-        rxn = A + B >> C
+        a,b,c = species('A B C')
+        rxn = a+b >> c
+
+    To create reactions
+
+    .. math::
+
+        A+B &\\underset{4.1}{\\stackrel{0.6}{\\rightleftharpoons}} 2C
+
+        C   &\\xrightarrow{5.2} D
+
+    use the following code:
+
+    .. code-block:: python
+
+        a,b,c,d = gpac.species('A B C D')
+        rxns = [
+            (a+b | 2*c).k(0.6).r(4.1),
+            (c >> d).k(5.2),
+        ]
     """
 
     reactants: Expression
@@ -425,12 +525,16 @@ class Reaction:
     """Rate constant of reverse reaction (only used if :py:data:`Reaction.reversible` is true)."""
 
     reversible: bool = False
-    """Whether reaction is reversible, i.e. products &rarr; reactants is a reaction also."""
+    """Whether reaction is reversible, i.e. `products` :math:`\\to` `reactants` is a reaction also."""
 
     def __init__(self, reactants: Union[Specie, Expression], products: Union[Specie, Expression],
                  k: float = 1, r: float = 1,
                  reversible: bool = False) -> None:
         """
+        In general this constructor should not be used directly; instead, use the operators ``>>``,
+        ``|``, ``+``, and ``*`` to construct reactions. (See description of :any:`Reaction` for
+        examples.)
+
         Args:
             reactants: left side of species in the reaction
             products: right side of species in the reaction
@@ -456,8 +560,8 @@ class Reaction:
 
         self.reactants = reactants
         self.products = products
-        self.rate_constant = float(k)
-        self.rate_constant_reverse = float(r)
+        self.rate_constant = k
+        self.rate_constant_reverse = r
         self.reversible = reversible
 
     def get_ode(self, specie: Specie) -> sympy.Expr:
@@ -469,8 +573,10 @@ class Reaction:
 
         Returns:
             sympy expression for the ODE term for the given :any:`Specie`.
-            For example, if the reaction is A+B &rarr; 2C, then the ODE for A is -k*A*B
-            the ODE for B is -k*A*B, and the ODE for C is 2*k*A*B.
+            For example, if the reaction is :math:`A+B \\to 2C`,
+            then the ODE for :math:`A` is :math:`-k \\cdot A \\cdot B`,
+            the ODE for B is :math:`-k \\cdot A \\cdot B`,
+            and the ODE for C is :math:`2 \\cdot k \\cdot A \\cdot B`.
         """
         if specie not in self.reactants.get_species() and specie not in self.products.get_species():
             return sympy.Integer(0)
@@ -587,12 +693,16 @@ class Reaction:
         return p1.name, p2.name
 
     def __str__(self) -> str:
-        rev_rate_str = f'({self.rate_constant_reverse})<' if self.reversible else ''
-        return f"{self.reactants} {rev_rate_str}-->({self.rate_constant}) {self.products}"
+        for_rate_str = '' if self.rate_constant == 1 else f'({self.rate_constant})'
+        rev_rate_str = '' if not self.reversible or self.rate_constant_reverse == 1 \
+            else f'({self.rate_constant_reverse})<'
+        return f"{self.reactants} {rev_rate_str}-->{for_rate_str} {self.products}"
 
     def __repr__(self) -> str:
         return (f"Reaction({repr(self.reactants)}, {repr(self.products)}, "
-                f"{self.rate_constant})")
+                f"rate_constant={self.rate_constant}, "
+                f"rate_constant_reverse={self.rate_constant_reverse}, "
+                f"reversible={self.reversible})")
 
     def k(self, coeff: float) -> Reaction:
         """
@@ -628,7 +738,7 @@ class Reaction:
         .. code-block:: python
 
             x, y, z = species("X Y Z")
-            rxns = [ (x + y | z).k(2.5).r(1.5) ]
+            rxn = (x + y | z).k(2.5).r(1.5)
 
         args:
             coeff: float
@@ -652,49 +762,6 @@ class Reaction:
         return tuple(all_species)
 
 
-# example of StochKit format:
-'''
-<Model>
-   <Description>Epidemic</Description>
-   <NumberOfReactions>1</NumberOfReactions>
-   <NumberOfSpecies>2</NumberOfSpecies>
-   <ParametersList>
-     <Parameter>
-       <Id>c1</Id>
-       <Expression>1.0</Expression>
-     </Parameter>
-   </ParametersList>
-   <ReactionsList>
-     <Reaction>
-       <Id>R2</Id>
-       <Description> A+B -> 2B </Description>
-       <Type>mass-action</Type>
-       <Rate>c1</Rate>
-       <Reactants>
-           <SpeciesReference id="A" stoichiometry="1"/>
-           <SpeciesReference id="B" stoichiometry="1"/>
-       </Reactants>
-       <Products>
-           <SpeciesReference id="B" stoichiometry="2"/>
-       </Products>
-     </Reaction>
-  </ReactionsList>
-  <SpeciesList>
-     <Species>
-       <Id>A</Id>
-       <Description>Species #1</Description>
-       <InitialPopulation>10000</InitialPopulation>
-     </Species>
-     <Species>
-       <Id>B</Id>
-       <Description>Species #2</Description>
-       <InitialPopulation>1</InitialPopulation>
-     </Species>
-  </SpeciesList>
-</Model>
-'''
-
-
 def species_in_rxns(rxns: Iterable[Reaction]) -> List[Specie]:
     """
     Args:
